{
    host: www.baidu.com,
    test: {
        url: tmpurl,
        val: 1,
        code: 1.99
    },
    result: {
        code: 1.99
    },
    test2: {
        headers: {
            content_type: "text/html; charset=utf-8"
        }
    }
}